#EPSG data in libspatialite should be in sync with our current GDAL version

# Geocallbacks work with SQLite 3.7.3 and up, available in Fedora,
# but not in EL, including 6; are off by default
%if 0%{?fedora}
%global _geocallback "--enable-geocallbacks"
%endif

# GEOS 3.3 is only available from F16 and EL6 on and up
# Older versions don't allow for "geosadvanced"
%if 0%{?rhel}

#TODO: Fails to build, reported by mail. If geosadvanced is disabled, linker flags miss geos_c
%global _geosadvanced "--disable-geosadvanced"
# Checks are known to fail if libspatialite is built without advancedgeos
%global _no_checks 1
%endif

Name:      libspatialite
Version:   3.1.0
Release:   0.3.RC2%{?dist}
Summary:   Enables SQLite to support spatial data
Group:     System Environment/Libraries
License:   MPLv1.1 or GPLv2+ or LGPLv2+
URL:       https://www.gaia-gis.it/fossil/libspatialite
#Source0:   http://www.gaia-gis.it/gaia-sins/%{name}-%{version}.tar.gz
# The RC was supplied personally by the developer
Source0:   http://www.gaia-gis.it/gaia-sins/%{name}-%{version}-RC2.tar.gz

BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

# EPEL 5 reminiscences are for ELGIS

BuildRequires: proj-devel
BuildRequires: freexl-devel
BuildRequires: sqlite-devel
BuildRequires: geos-devel

# Doesn't build on ppc or ppc64
# https://bugzilla.redhat.com/show_bug.cgi?id=663938
# https://bugzilla.redhat.com/show_bug.cgi?id=846301
# 3.1.0 RC3 solves this issue
ExcludeArch:   ppc ppc64

%description
SpatiaLite is a a library extending the basic SQLite core
in order to get a full fledged Spatial DBMS, really simple
and lightweight, but mostly OGC-SFS compliant.

%package devel
Summary:  Development libraries and headers for SpatiaLite
Group:    Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: pkgconfig

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%setup -q -n %{name}-%{version}-RC2


%build
%configure \
    --disable-static \
    %{?_geocallback}   \
    %{?_geosadvanced}

make %{?_smp_mflags}


%install
rm -rf %{buildroot}

make install DESTDIR=%{buildroot}

# Delete undesired libtool archives
rm -f %{buildroot}/%{_libdir}/%{name}.la


%check
#TODO: Tests don't respect destdir, it seems
# Doesn't respect missing FreeXl -- e-mailed the author
make check


%clean
rm -rf %{buildroot}


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files 
%doc COPYING AUTHORS
%{_libdir}/%{name}.so.*

%files devel
%doc examples/*.c
%{_includedir}/spatialite.h
%{_includedir}/spatialite
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/spatialite.pc


%changelog
* Sat Aug 18 2012 Volker Fröhlich <volker27@gmx.at> - 3.1.0-0.3.RC2
- Add ppc to excluded archs (BZ #846301)
- Don't build with profiling

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.0-0.2.RC2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 27 2012 Volker Fröhlich <volker27@gmx.at> - 3.1.0-0.1.RC2
- Add pkconfig as Requirement to the devel sub-package
- Drop freexl patch (solved), build with Freexl
- Update descriptions and summaries
- Re-design conditionals for build flags
- Don't run checks if built without advancedgeos
- Include examples as documentation

* Wed Jan 14 2012 Volker Fröhlich <volker27@gmx.at> - 3.0.1-1
- New upstream release
- Drop defattr
- Run tests
- Own spatialite include-dir
- Add GPLv2+ and LGPLv2+ as alternative licenses
- Update URL and source URL
- Reduce build conditions to EPEL or not
- Use isa macro in base package Requires

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.0-0.7.RC4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.0-0.6.RC4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Dec 7 2010 Volker Fröhlich <volker27@gmx.at> 2.4.0-0.5.RC4
- Corrected wrong Fedora version number in if-statement

* Sun Dec 5 2010 Volker Fröhlich <volker27@gmx.at> 2.4.0-0.4.RC4
- Refined configure condition to support RHEL

* Fri Dec 3 2010 Volker Fröhlich <volker27@gmx.at> 2.4.0-0.3.RC4
- Added buildroot
- Added doc files

* Wed Dec 1 2010 Volker Fröhlich <volker27@gmx.at> 2.4.0-0.2.RC4
- Added description of devel package
- Switched to disable-static flag

* Sun Nov 28 2010 Volker Fröhlich <volker27@gmx.at> 2.4.0-0.1.RC4
- Initial packaging for Fedora
